==> haskell-sqlite-simple-0.4.18.2-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sqlite-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 sqlite-simple
version:              0.4.18.2
visibility:           public
id:                   sqlite-simple-0.4.18.2-Cgg4oZwx7aiLOLF3e6zKQF
key:                  sqlite-simple-0.4.18.2-Cgg4oZwx7aiLOLF3e6zKQF
license:              BSD-3-Clause
copyright:
    (c) 2011 MailRank, Inc.,
    (c) 2011-2012 Leon P Smith,
    (c) 2012-2014 Janne Hellsten

maintainer:           Janne Hellsten <jjhellst@gmail.com>
author:               Bryan O'\''Sullivan, Leon P Smith, Janne Hellsten
stability:            stable
homepage:             http://github.com/nurpax/sqlite-simple
synopsis:             Mid-Level SQLite client library
description:
    Mid-level SQLite client library, based on postgresql-simple.

    Main documentation (with examples): <docs/Database-SQLite-Simple.html Database.SQLite.Simple>

    You can view the project page at <http://github.com/nurpax/sqlite-simple>
    for more information.

category:             Database
abi:                  dfe3eb8af474f058bc2ccc047e55c17d
exposed:              True
exposed-modules:
    Database.SQLite.Simple Database.SQLite.Simple.FromField
    Database.SQLite.Simple.FromRow Database.SQLite.Simple.Function
    Database.SQLite.Simple.Internal Database.SQLite.Simple.Ok
    Database.SQLite.Simple.QQ Database.SQLite.Simple.Time
    Database.SQLite.Simple.Time.Implementation
    Database.SQLite.Simple.ToField Database.SQLite.Simple.ToRow
    Database.SQLite.Simple.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/sqlite-simple-0.4.18.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/sqlite-simple-0.4.18.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sqlite-simple
hs-libraries:         HSsqlite-simple-0.4.18.2-Cgg4oZwx7aiLOLF3e6zKQF
depends:
    Only-0.1-L8QgoWg4Wjg75H1UNFo3nI
    attoparsec-0.14.4-1cvWowE4NeVTtjhbiJiE3 base-4.15.1.0
    blaze-builder-0.4.2.2-2gLNFpRfQ1I6uT3J9lURjU
    blaze-textual-0.2.2.1-kwmw7wGaRT2ChwDK7FWxQ bytestring-0.10.12.1
    containers-0.6.4.1 direct-sqlite-2.3.27-5hGyU16arCOEmqh4SCKL7X
    template-haskell-2.17.0.0 text-1.2.5.0 time-1.9.3
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-sqlite-simple/html/sqlite-simple.haddock

haddock-html:         /usr/share/doc/haskell-sqlite-simple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sqlite-simple-0.4.18.2-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sqlite-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 sqlite-simple
version:              0.4.18.2
visibility:           public
id:                   sqlite-simple-0.4.18.2-IbZiS3qaLe68ahyEzxySu0
key:                  sqlite-simple-0.4.18.2-IbZiS3qaLe68ahyEzxySu0
license:              BSD-3-Clause
copyright:
    (c) 2011 MailRank, Inc.,
    (c) 2011-2012 Leon P Smith,
    (c) 2012-2014 Janne Hellsten

maintainer:           Janne Hellsten <jjhellst@gmail.com>
author:               Bryan O'\''Sullivan, Leon P Smith, Janne Hellsten
stability:            stable
homepage:             http://github.com/nurpax/sqlite-simple
synopsis:             Mid-Level SQLite client library
description:
    Mid-level SQLite client library, based on postgresql-simple.

    Main documentation (with examples): <docs/Database-SQLite-Simple.html Database.SQLite.Simple>

    You can view the project page at <http://github.com/nurpax/sqlite-simple>
    for more information.

category:             Database
abi:                  7c7fe35084c869ada84c7905aa6b283c
exposed:              True
exposed-modules:
    Database.SQLite.Simple Database.SQLite.Simple.FromField
    Database.SQLite.Simple.FromRow Database.SQLite.Simple.Function
    Database.SQLite.Simple.Internal Database.SQLite.Simple.Ok
    Database.SQLite.Simple.QQ Database.SQLite.Simple.Time
    Database.SQLite.Simple.Time.Implementation
    Database.SQLite.Simple.ToField Database.SQLite.Simple.ToRow
    Database.SQLite.Simple.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/sqlite-simple-0.4.18.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/sqlite-simple-0.4.18.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sqlite-simple
hs-libraries:         HSsqlite-simple-0.4.18.2-IbZiS3qaLe68ahyEzxySu0
depends:
    Only-0.1-L8QgoWg4Wjg75H1UNFo3nI
    attoparsec-0.14.4-9KhLweOrk4jAI2XTloxgeh base-4.15.1.0
    blaze-builder-0.4.2.2-2gLNFpRfQ1I6uT3J9lURjU
    blaze-textual-0.2.3.1-BiYQsUAE6zg2HFc3bX4wyt bytestring-0.10.12.1
    containers-0.6.4.1 direct-sqlite-2.3.28-LNP1LuRvSFBJ8GCBvnb6uW
    template-haskell-2.17.0.0 text-1.2.5.0 time-1.9.3
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-sqlite-simple/html/sqlite-simple.haddock

haddock-html:         /usr/share/doc/haskell-sqlite-simple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
